==> jc-1.4.0.tar.gz: java/beans/PropertyChangeListenerProxy.h <==
// public class java.beans.PropertyChangeListenerProxy

// class file dependencies
// @dep_class 8ac43ffc5c8f8916 java_beans_PropertyChangeListenerProxy
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_util_EventListenerProxy

#include "java/util/EventListenerProxy.h"

#ifndef _JC_java_beans_PropertyChangeListenerProxy_H_
#define _JC_java_beans_PropertyChangeListenerProxy_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_beans_PropertyChangeListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_PropertyChangeListenerProxy$sub_refs	_jc_java_beans_PropertyChangeListenerProxy$sub_refs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs	_jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$refs	_jc_java_beans_PropertyChangeListenerProxy$refs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$nonrefs	_jc_java_beans_PropertyChangeListenerProxy$nonrefs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$object	_jc_java_beans_PropertyChangeListenerProxy$object;

typedef const struct _jc_java_beans_PropertyChangeListenerProxy$vmethods	_jc_java_beans_PropertyChangeListenerProxy$vmethods;
typedef const struct _jc_java_beans_PropertyChangeListenerProxy$vtable	_jc_java_beans_PropertyChangeListenerProxy$vtable;
typedef const struct _jc_java_beans_PropertyChangeListenerProxy$vtype	_jc_java_beans_PropertyChangeListenerProxy$vtype;

// Constructors
extern void _jc_java_beans_PropertyChangeListenerProxy$method$_init$a84cb94cf083c1ac(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_beans_PropertyChangeListenerProxy$method$getPropertyName$3ce73dcd3d514390(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *);
extern void _jc_java_beans_PropertyChangeListenerProxy$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_PropertyChangeListenerProxy$method_info$getPropertyName$3ce73dcd3d514390;
extern _jc_method _jc_java_beans_PropertyChangeListenerProxy$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_java_beans_PropertyChangeListenerProxy$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyName$3ce73dcd3d514390)(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *);
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_java_beans_PropertyChangeListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
	_jc_java_beans_PropertyChangeListenerProxy$vmethods	java_beans_PropertyChangeListenerProxy;
};

// Vtype
struct _jc_java_beans_PropertyChangeListenerProxy$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyChangeListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeListenerProxy$sub_refs {
	struct _jc_java_lang_String$object	*propertyName;
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyChangeListenerProxy$refs {
    _jc_java_beans_PropertyChangeListenerProxy$sub_refs	java_beans_PropertyChangeListenerProxy;
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyChangeListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
    _jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs	java_beans_PropertyChangeListenerProxy;
};

// Object instance structure
struct _jc_java_beans_PropertyChangeListenerProxy$object {
	_jc_java_beans_PropertyChangeListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyChangeListenerProxy$vtype	*vtype;
	_jc_java_beans_PropertyChangeListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyChangeListenerProxy$vtype _jc_java_beans_PropertyChangeListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyChangeListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyChangeListenerProxy$class_object;

#endif	/* _JC_java_beans_PropertyChangeListenerProxy_H_ */

==> jc-1.4.6.tar.gz: java/beans/PropertyChangeListenerProxy.h <==
// public class java.beans.PropertyChangeListenerProxy

// class file dependencies
// @dep_class 8ac43ffc5c8f8916 java_beans_PropertyChangeListenerProxy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_util_EventListenerProxy

#include "java/util/EventListenerProxy.h"

#ifndef _JC_java_beans_PropertyChangeListenerProxy_H_
#define _JC_java_beans_PropertyChangeListenerProxy_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_beans_PropertyChangeListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_PropertyChangeListenerProxy$sub_refs	_jc_java_beans_PropertyChangeListenerProxy$sub_refs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs	_jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$refs	_jc_java_beans_PropertyChangeListenerProxy$refs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$nonrefs	_jc_java_beans_PropertyChangeListenerProxy$nonrefs;
typedef struct _jc_java_beans_PropertyChangeListenerProxy$object	_jc_java_beans_PropertyChangeListenerProxy$object;

typedef const struct _jc_java_beans_PropertyChangeListenerProxy$vmethods	_jc_java_beans_PropertyChangeListenerProxy$vmethods;
typedef const struct _jc_java_beans_PropertyChangeListenerProxy$vtable	_jc_java_beans_PropertyChangeListenerProxy$vtable;
typedef const struct _jc_java_beans_PropertyChangeListenerProxy$vtype	_jc_java_beans_PropertyChangeListenerProxy$vtype;

// Constructors
extern void _jc_java_beans_PropertyChangeListenerProxy$method$_init$a84cb94cf083c1ac(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_beans_PropertyChangeListenerProxy$method$getPropertyName$3ce73dcd3d514390(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_PropertyChangeListenerProxy$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_PropertyChangeListenerProxy$method_info$getPropertyName$3ce73dcd3d514390;
extern _jc_method _jc_java_beans_PropertyChangeListenerProxy$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_java_beans_PropertyChangeListenerProxy$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyName$3ce73dcd3d514390)(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *) _JC_JCNI_ATTR;
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_java_beans_PropertyChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_PropertyChangeListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
	_jc_java_beans_PropertyChangeListenerProxy$vmethods	java_beans_PropertyChangeListenerProxy;
};

// Vtype
struct _jc_java_beans_PropertyChangeListenerProxy$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyChangeListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeListenerProxy$sub_refs {
	struct _jc_java_lang_String$object	*propertyName;
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyChangeListenerProxy$refs {
    _jc_java_beans_PropertyChangeListenerProxy$sub_refs	java_beans_PropertyChangeListenerProxy;
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyChangeListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
    _jc_java_beans_PropertyChangeListenerProxy$sub_nonrefs	java_beans_PropertyChangeListenerProxy;
};

// Object instance structure
struct _jc_java_beans_PropertyChangeListenerProxy$object {
	_jc_java_beans_PropertyChangeListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyChangeListenerProxy$vtype	*vtype;
	_jc_java_beans_PropertyChangeListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyChangeListenerProxy$vtype _jc_java_beans_PropertyChangeListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyChangeListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyChangeListenerProxy$class_object;

#endif	/* _JC_java_beans_PropertyChangeListenerProxy_H_ */
